@@ -1,4 +1,4 @@
-from agrirouter.onboarding.signature import create_signature
+#from agrirouter.onboarding.signature import create_signature
 from agrirouter.revoking.headers import RevokingHeader
 from agrirouter.revoking.request_body import RevokingBody
 
@@ -21,14 +21,14 @@ class RevokingRequest:
     def get_body_content(self):
         return self.body.json().replace("\n", "")
 
-    def sign(self, private_key):
-        body = self.get_body_content()
-        signature = create_signature(body, private_key)
-        self.header.sign(signature)
+#    def sign(self, private_key):
+#        body = self.get_body_content()
+#        signature = create_signature(body, private_key)
+#        self.header.sign(signature)
 
-    @property
-    def is_signed(self) -> bool:
-        header_has_signature = self.get_header().get("X-Agrirouter-Signature", None)
-        if header_has_signature:
-            return True
-        return False
+#    @property
+#    def is_signed(self) -> bool:
+#        header_has_signature = self.get_header().get("X-Agrirouter-Signature", None)
+#        if header_has_signature:
+#            return True
+#        return False
